@@ -23,20 +23,15 @@ function(hljs) {
       },
       {
         className: 'class',
-        beginWithKeyword: true, end: '{',
+        beginKeywords: 'class interface', end: '{',
         illegal: ':',
-        keywords: 'class interface',
         contains: [
           {
             className: 'inheritance',
-            beginWithKeyword: true,
-            keywords: 'extends implements',
+            beginKeywords: 'extends implements',
             relevance: 10
           },
-          {
-            className: 'title',
-            begin: hljs.UNDERSCORE_IDENT_RE
-          }
+          hljs.UNDERSCORE_TITLE_MODE
         ]
       }
     ]
