@@ -4,12 +4,17 @@ Author: Evgeny Stepanischev <imbolk@gmail.com>
 */
 
 function(hljs){
+  var LITERAL = {
+    className: 'literal',
+    begin: '[\\+\\-]',
+    relevance: 0
+  };
   return {
     contains: [
       {
         className: 'comment',
         begin: '[^\\[\\]\\.,\\+\\-<> \r\n]',
-        excludeEnd: true,
+        returnEnd: true,
         end: '[\\[\\]\\.,\\+\\-<> \r\n]',
         relevance: 0
       },
@@ -20,12 +25,15 @@ function(hljs){
       },
       {
         className: 'string',
-        begin: '[\\.,]'
+        begin: '[\\.,]',
+        relevance: 0
       },
       {
-        className: 'literal',
-        begin: '[\\+\\-]'
-      }
+        // this mode works as the only relevance counter
+        begin: /\+\+|\-\-/, returnBegin: true,
+        contains: [LITERAL]
+      },
+      LITERAL
     ]
   };
 }
